[][src]Struct mdbook::renderer::RenderContext

pub struct RenderContext {
    pub version: String,
    pub root: PathBuf,
    pub book: Book,
    pub config: Config,
    pub destination: PathBuf,
    // some fields omitted
}

The context provided to all renderers.

Fields

version: String

Which version of mdbook did this come from (as written in mdbook's Cargo.toml). Useful if you know the renderer is only compatible with certain versions of mdbook.

root: PathBuf

The book's root directory.

book: Book

A loaded representation of the book itself.

config: Config

The loaded configuration file.

destination: PathBuf

Where the renderer must put any build artefacts generated. To allow renderers to cache intermediate results, this directory is not guaranteed to be empty or even exist.

Methods

impl RenderContext[src]

pub fn new<P, Q>(
    root: P,
    book: Book,
    config: Config,
    destination: Q
) -> RenderContext where
    P: Into<PathBuf>,
    Q: Into<PathBuf>, 
[src]

Create a new RenderContext.

pub fn source_dir(&self) -> PathBuf[src]

Get the source directory's (absolute) path on disk.

pub fn from_json<R: Read>(reader: R) -> Result<RenderContext>[src]

Load a RenderContext from its JSON representation.